@@ -19,6 +19,7 @@ use HTTP::Tiny;
 use Time::HiRes qw(sleep);
 use URI::Escape qw(uri_escape);
 use version;
+use WWW::RT::CPAN;
 
 Readonly my %config => (
 	github_user => 'nigelhorne',
@@ -155,6 +156,10 @@ push @html, <<"HTML";
 			background: #fffbeb;
 			padding: 0.5em 1em;
 		}
+		.notice.rt-issues {
+			background: #fff6e5;
+			border-left: 4px solid #d9822b;
+		}
 	</style>
 </head>
 <body>
@@ -752,11 +757,29 @@ HTML
 push @html, '<p><center>Use mouse wheel or pinch to zoom; drag to pan</center></p>';
 
 # -------------------------------
-# Add CPAN Testers failing reports table
+# Issues flagged on RT
+# -------------------------------
+{
+	my $rt_count = fetch_open_rt_ticket_count($config{github_repo});
+	my $rt_url = "https://rt.cpan.org/Public/Dist/Display.html?Name=$config{github_repo}";
+
+	if(defined $rt_count && $rt_count > 0) {
+		push @html, '<p class="notice rt-issues">',
+			'<strong>RT issues:</strong>',
+			"<a href=\"$rt_url\" target=\"_blank\" rel=\"noopener\">",
+			"$rt_count open ticket" . @{[ $rt_count == 1 ? '' : 's' ]},
+			'</a>',
+			'</p>';
+	} else {
+		push @html, "<p>No issues active on <a href=\"$rt_url\">RT</a></p>";
+	}
+}
+
+# -------------------------------
+# CPAN Testers failing reports table
 # -------------------------------
 my $dist_name = $config{github_repo};	# e.g., CGI-Info
-my $cpan_api = "https://api.cpantesters.org/v3/summary/"
-		. uri_escape($dist_name);
+my $cpan_api = "https://api.cpantesters.org/v3/summary/" . uri_escape($dist_name);
 
 my $http = HTTP::Tiny->new(agent => 'cpan-coverage-html/1.0', timeout => 15);
 
@@ -788,7 +811,7 @@ if($success) {
 		push @versions, $release->{version};
 	}
 
-	@versions = sort { version->parse($b) <=> version->parse($a) } @versions;
+	@versions = sort { parse_version($b) <=> parse_version($a) } @versions;
 
 	$version = $versions[0];	# current
 	$prev_version = $versions[1];	# previous (may be undef)
@@ -830,8 +853,8 @@ if($version) {
 			my %dep_stats;
 
 			# Split GUIDs by grade
-			my @fail_guids = map { $_->{guid} } grep { ($_->{grade} // '') eq 'FAIL' } @fail_reports;
-			my @unknown_guids = map { $_->{guid} } grep { ($_->{grade} // '') eq 'UNKNOWN' } @fail_reports;
+			my @fail_guids = map { $_->{guid} } grep { lc($_->{grade} // '') eq 'fail' } @fail_reports;
+			my @unknown_guids = map { $_->{guid} } grep { lc($_->{grade} // '') eq 'unknown' } @fail_reports;
 
 			# FAIL reports
 			aggregate_dependency_stats(
@@ -903,19 +926,19 @@ if($version) {
 			);
 
 			if ($perl_cliff) {
-				my $perl_cutoff = version->parse($perl_cliff->{fails_up_to});
+				my $perl_cutoff = parse_version($perl_cliff->{fails_up_to});
 
 				my $fail_support = 0;
 				my $pass_contra = 0;
 
 				for my $r (@fail_reports) {
 					next unless $r->{perl};
-					$fail_support++ if version->parse($r->{perl}) < $perl_cutoff;
+					$fail_support++ if parse_version($r->{perl}) < $perl_cutoff;
 				}
 
 				for my $r (@pass_reports) {
 					next unless $r->{perl};
-					$pass_contra++ if version->parse($r->{perl}) < $perl_cutoff;
+					$pass_contra++ if parse_version($r->{perl}) < $perl_cutoff;
 				}
 				my ($score, $label) = confidence_score(
 					fail => $fail_support,
@@ -1187,7 +1210,7 @@ HTML
 		push @html, '</tbody></table>';
 	} else {
 		# @fail_reports is empty
-		push @html, "<p>No CPAN Testers failures reported for $dist_name $version.</p>";
+		push @html, "<p>No CPAN Testers failures reported for $dist_name $version</p>";
 	}
 } elsif($res->{status} == 404) {	# 404 means no fail reports
 	# push @html, "<A HREF=\"$cpan_api\">$cpan_api</A>";
@@ -1289,7 +1312,8 @@ sub aggregate_dependency_stats {
 }
 
 sub fetch_report_html {
-	my ($guid) = @_;
+	my $guid = $_[0];
+
 	return unless $guid;
 
 	my $url = "https://www.cpantesters.org/cpan/report/$guid";
@@ -1307,13 +1331,16 @@ sub extract_installed_modules {
 
 	return \%mods unless $html;
 
-	while ($html =~ /^\s*([A-Z]\w*(?:::\w+)*)\s+v?([\d._]+)/mg) {
-		my ($module, $version) = ($1, $2);
+	if ($html =~ /Installed modules:(.*?)(?:\n\n|\z)/s) {
+		my $block = $1;
+		while ($block =~ /^\s*([A-Z]\w*(?:::\w+)*)\s+v?([\d._]+)/mg) {
+			my ($module, $version) = ($1, $2);
 
-		# skip obvious noise
-		next if $module =~ /^(Perl|OS|Reporter|Tester)$/;
+			# skip obvious noise
+			next if $module =~ /^(Perl|OS|Reporter|Tester)$/;
 
-		$mods{$module} = $version;
+			$mods{$module} = $version;
+		}
 	}
 
 	return \%mods;
@@ -1384,11 +1411,11 @@ sub detect_version_cliffs {
 
 		next unless $d->{fail} && $d->{pass};
 
-		my @fail = sort { version->parse($a) <=> version->parse($b) } @{ $d->{fail} };
-		my @pass = sort { version->parse($a) <=> version->parse($b) } @{ $d->{pass} };
+		my @fail = sort { parse_version($a) <=> parse_version($b) } @{ $d->{fail} };
+		my @pass = sort { parse_version($a) <=> parse_version($b) } @{ $d->{pass} };
 
-		my $fail_min = version->parse($fail[0]);
-		my $pass_max = version->parse($pass[-1]);
+		my $fail_min = parse_version($fail[0]);
+		my $pass_max = parse_version($pass[-1]);
 
 		# Classic cliff: PASS versions entirely below FAIL versions
 		if ($pass_max < $fail_min) {
@@ -1408,7 +1435,7 @@ sub detect_version_cliffs {
 		my $fail_median = $fail[ int(@fail / 2) ];
 		my $pass_median = $pass[ int(@pass / 2) ];
 
-		if (version->parse($fail_median) > version->parse($pass_median)) {
+		if (parse_version($fail_median) > parse_version($pass_median)) {
 			push @suspects, {
 				module => $mod,
 				type => 'soft',
@@ -1446,7 +1473,7 @@ sub extract_perl_versions {
 
 	for my $r (@$reports) {
 		next unless $r->{perl};
-		push @v, version->parse($r->{perl});
+		push @v, parse_version($r->{perl});
 	}
 
 	return @v;
@@ -1512,7 +1539,7 @@ sub perl_series {
 }
 
 sub extract_locale {
-	my ($r) = @_;
+	my $r = $_[0];
 
 	# Preferred: explicit environment
 	for my $k (qw(LANG LC_ALL LC_CTYPE)) {
@@ -1551,3 +1578,22 @@ sub is_non_english_locale {
 
 	return 1;
 }
+
+sub parse_version {
+	my $v = $_[0];
+	return eval { version->parse($v) };
+}
+
+sub fetch_open_rt_ticket_count {
+	my $dist = $_[0];
+
+	my @rc = @{WWW::RT::CPAN::list_dist_active_tickets(dist => $dist)};
+
+	# Defensive checks
+	return undef unless @rc >= 3;
+	return undef unless $rc[0] == 200 && $rc[1] eq 'OK';
+
+	my $tickets = $rc[2] && ref $rc[2] eq 'ARRAY' ? $rc[2] : [];
+
+	return scalar @$tickets;
+}
